
/***** begin user configuration section *****/

/* Define this if you want to use Xdf */
#undef USE_XDF


/* Define this if you use mtools together with Solaris' vold */
#undef USING_VOLD


/* Define this if you use mtools together with the new Solaris' vold
 * support */
#undef USING_NEW_VOLD


/* Define for debugging messages */
#undef DEBUG


/* Define on non Unix OS'es which don't have the concept of tty's */
#undef USE_RAWTERM


/* Define when sys_errlist is defined in the standard include files */
#undef DECL_SYS_ERRLIST
